==> estateplat-common-1.2.3-20180208.064337-27-sources.jar: cn/gtmap/estateplat/model/resources/core/ZrzyXm.java <==
package cn.gtmap.estateplat.model.resources.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2017-4-18
 * @description 自然资源项目表
 */
@Table(name = "zrzy_xm")
public class ZrzyXm implements InsertVo {
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 项目ID
     */
    @Id
    private String proid;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 工作流定义ID
     */
    private String wiid;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 受理编号
     */
    private String slbh;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 业务编码
     */
    private String ywbm;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 行政区代码
     */
    private String xzqdm;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 行政区名称
     */
    private String xzqmc;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 项目创建人名称
     */
    private String cjrmc;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 项目创建人ID
     */
    private String cjrid;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 创建时间
     */
    private Date cjsj;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 办结时间
     */
    private Date bjsj;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 项目名称
     */
    private String xmmc;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 登记事由
     */
    private String djsy;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 案件状态
     */
    private String ajzt;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 登记机构
     */
    private String djjg;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 备注
     */
    private String bz;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 收件人
     */
    private String sjr;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 收件日期
     */
    private Date sjrq;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 收件信息备注
     */
    private String sjxxbz;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 自然资源单元号
     */
    private String zrzydyh;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 自然资源单元类型
     */
    private String zrzydylx;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 权利类型
     */
    private String qllx;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 坐落
     */
    private String zl;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 总面积
     */
    private Double zmj;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 总数量
     */
    private Integer zsl;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 面积单位
     */
    private String mjdw;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 权属状态
     */
    private String qszt;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 登簿人
     */
    private String dbr;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 登簿时间
     */
    private Date dbsj;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 附记
     */
    private String fj;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 申请人
     */
    private String sqr;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 代理人
     */
    private String dlr;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 申请人签字日期
     */
    private Date sqrqzrq;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 所有权人
     */
    private String syqr;

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getWiid() {
        return wiid;
    }

    public void setWiid(String wiid) {
        this.wiid = wiid;
    }

    public String getSlbh() {
        return slbh;
    }

    public void setSlbh(String slbh) {
        this.slbh = slbh;
    }

    public String getYwbm() {
        return ywbm;
    }

    public void setYwbm(String ywbm) {
        this.ywbm = ywbm;
    }

    public String getXzqdm() {
        return xzqdm;
    }

    public void setXzqdm(String xzqdm) {
        this.xzqdm = xzqdm;
    }

    public String getXzqmc() {
        return xzqmc;
    }

    public void setXzqmc(String xzqmc) {
        this.xzqmc = xzqmc;
    }

    public String getCjrmc() {
        return cjrmc;
    }

    public void setCjrmc(String cjrmc) {
        this.cjrmc = cjrmc;
    }

    public String getCjrid() {
        return cjrid;
    }

    public void setCjrid(String cjrid) {
        this.cjrid = cjrid;
    }

    public Date getCjsj() {
        return cjsj;
    }

    public void setCjsj(Date cjsj) {
        this.cjsj = cjsj;
    }

    public Date getBjsj() {
        return bjsj;
    }

    public void setBjsj(Date bjsj) {
        this.bjsj = bjsj;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getDjsy() {
        return djsy;
    }

    public void setDjsy(String djsy) {
        this.djsy = djsy;
    }

    public String getAjzt() {
        return ajzt;
    }

    public void setAjzt(String ajzt) {
        this.ajzt = ajzt;
    }

    public String getDjjg() {
        return djjg;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getSjr() {
        return sjr;
    }

    public void setSjr(String sjr) {
        this.sjr = sjr;
    }

    public Date getSjrq() {
        return sjrq;
    }

    public void setSjrq(Date sjrq) {
        this.sjrq = sjrq;
    }

    public String getSjxxbz() {
        return sjxxbz;
    }

    public void setSjxxbz(String sjxxbz) {
        this.sjxxbz = sjxxbz;
    }

    public String getZrzydyh() {
        return zrzydyh;
    }

    public void setZrzydyh(String zrzydyh) {
        this.zrzydyh = zrzydyh;
    }

    public String getZrzydylx() {
        return zrzydylx;
    }

    public void setZrzydylx(String zrzydylx) {
        this.zrzydylx = zrzydylx;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public Double getZmj() {
        return zmj;
    }

    public void setZmj(Double zmj) {
        this.zmj = zmj;
    }

    public Integer getZsl() {
        return zsl;
    }

    public void setZsl(Integer zsl) {
        this.zsl = zsl;
    }

    public String getMjdw() {
        return mjdw;
    }

    public void setMjdw(String mjdw) {
        this.mjdw = mjdw;
    }

    public String getQszt() {
        return qszt;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public Date getDbsj() {
        return dbsj;
    }

    public void setDbsj(Date dbsj) {
        this.dbsj = dbsj;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getSqr() {
        return sqr;
    }

    public void setSqr(String sqr) {
        this.sqr = sqr;
    }

    public String getDlr() {
        return dlr;
    }

    public void setDlr(String dlr) {
        this.dlr = dlr;
    }

    public Date getSqrqzrq() {
        return sqrqzrq;
    }

    public void setSqrqzrq(Date sqrqzrq) {
        this.sqrqzrq = sqrqzrq;
    }

    public String getSyqr() {
        return syqr;
    }

    public void setSyqr(String syqr) {
        this.syqr = syqr;
    }
}

==> estateplat-common-1.2.3-20180301.090929-36-sources.jar: cn/gtmap/estateplat/model/resources/core/ZrzyXm.java <==
package cn.gtmap.estateplat.model.resources.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2017-4-18
 * @description 自然资源项目表
 */
@Table(name = "zrzy_xm")
public class ZrzyXm implements InsertVo {
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 项目ID
     */
    @Id
    private String proid;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 工作流定义ID
     */
    private String wiid;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 受理编号
     */
    private String slbh;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 业务编码
     */
    private String ywbm;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 行政区代码
     */
    private String xzqdm;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 行政区名称
     */
    private String xzqmc;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 项目创建人名称
     */
    private String cjrmc;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 项目创建人ID
     */
    private String cjrid;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 创建时间
     */
    private Date cjsj;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 办结时间
     */
    private Date bjsj;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 项目名称
     */
    private String xmmc;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 登记事由
     */
    private String djsy;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 案件状态
     */
    private String ajzt;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 登记机构
     */
    private String djjg;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 备注
     */
    private String bz;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 收件人
     */
    private String sjr;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 收件日期
     */
    private Date sjrq;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 收件信息备注
     */
    private String sjxxbz;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 自然资源单元号
     */
    private String zrzydyh;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 自然资源单元类型
     */
    private String zrzydylx;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 权利类型
     */
    private String qllx;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 坐落
     */
    private String zl;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 总面积
     */
    private Double zmj;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 总数量
     */
    private Integer zsl;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 面积单位
     */
    private String mjdw;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 权属状态
     */
    private String qszt;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 登簿人
     */
    private String dbr;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 登簿时间
     */
    private Date dbsj;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 附记
     */
    private String fj;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 申请人
     */
    private String sqr;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 代理人
     */
    private String dlr;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 申请人签字日期
     */
    private Date sqrqzrq;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 所有权人
     */
    private String syqr;

    private String yyclsddz;//异议材料送达地址
    private Date yyclsdrq;//异议材料送达日期
    private String lxdh;//联系电话

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getWiid() {
        return wiid;
    }

    public void setWiid(String wiid) {
        this.wiid = wiid;
    }

    public String getSlbh() {
        return slbh;
    }

    public void setSlbh(String slbh) {
        this.slbh = slbh;
    }

    public String getYwbm() {
        return ywbm;
    }

    public void setYwbm(String ywbm) {
        this.ywbm = ywbm;
    }

    public String getXzqdm() {
        return xzqdm;
    }

    public void setXzqdm(String xzqdm) {
        this.xzqdm = xzqdm;
    }

    public String getXzqmc() {
        return xzqmc;
    }

    public void setXzqmc(String xzqmc) {
        this.xzqmc = xzqmc;
    }

    public String getCjrmc() {
        return cjrmc;
    }

    public void setCjrmc(String cjrmc) {
        this.cjrmc = cjrmc;
    }

    public String getCjrid() {
        return cjrid;
    }

    public void setCjrid(String cjrid) {
        this.cjrid = cjrid;
    }

    public Date getCjsj() {
        return cjsj;
    }

    public void setCjsj(Date cjsj) {
        this.cjsj = cjsj;
    }

    public Date getBjsj() {
        return bjsj;
    }

    public void setBjsj(Date bjsj) {
        this.bjsj = bjsj;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getDjsy() {
        return djsy;
    }

    public void setDjsy(String djsy) {
        this.djsy = djsy;
    }

    public String getAjzt() {
        return ajzt;
    }

    public void setAjzt(String ajzt) {
        this.ajzt = ajzt;
    }

    public String getDjjg() {
        return djjg;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getSjr() {
        return sjr;
    }

    public void setSjr(String sjr) {
        this.sjr = sjr;
    }

    public Date getSjrq() {
        return sjrq;
    }

    public void setSjrq(Date sjrq) {
        this.sjrq = sjrq;
    }

    public String getSjxxbz() {
        return sjxxbz;
    }

    public void setSjxxbz(String sjxxbz) {
        this.sjxxbz = sjxxbz;
    }

    public String getZrzydyh() {
        return zrzydyh;
    }

    public void setZrzydyh(String zrzydyh) {
        this.zrzydyh = zrzydyh;
    }

    public String getZrzydylx() {
        return zrzydylx;
    }

    public void setZrzydylx(String zrzydylx) {
        this.zrzydylx = zrzydylx;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public Double getZmj() {
        return zmj;
    }

    public void setZmj(Double zmj) {
        this.zmj = zmj;
    }

    public Integer getZsl() {
        return zsl;
    }

    public void setZsl(Integer zsl) {
        this.zsl = zsl;
    }

    public String getMjdw() {
        return mjdw;
    }

    public void setMjdw(String mjdw) {
        this.mjdw = mjdw;
    }

    public String getQszt() {
        return qszt;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public Date getDbsj() {
        return dbsj;
    }

    public void setDbsj(Date dbsj) {
        this.dbsj = dbsj;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getSqr() {
        return sqr;
    }

    public void setSqr(String sqr) {
        this.sqr = sqr;
    }

    public String getDlr() {
        return dlr;
    }

    public void setDlr(String dlr) {
        this.dlr = dlr;
    }

    public Date getSqrqzrq() {
        return sqrqzrq;
    }

    public void setSqrqzrq(Date sqrqzrq) {
        this.sqrqzrq = sqrqzrq;
    }

    public String getSyqr() {
        return syqr;
    }

    public void setSyqr(String syqr) {
        this.syqr = syqr;
    }

    public String getYyclsddz() {
        return yyclsddz;
    }

    public void setYyclsddz(String yyclsddz) {
        this.yyclsddz = yyclsddz;
    }

    public Date getYyclsdrq() {
        return yyclsdrq;
    }

    public void setYyclsdrq(Date yyclsdrq) {
        this.yyclsdrq = yyclsdrq;
    }

    public String getLxdh() {
        return lxdh;
    }

    public void setLxdh(String lxdh) {
        this.lxdh = lxdh;
    }
}
